@@ -10,8 +10,8 @@ from python_jsonschema_objects.util import lazy_format as fmt
 logger = logging.getLogger(__name__)
 
 
-class ArrayWrapper(collections.MutableSequence):
-    """ A wrapper for array-like structures.
+class ArrayWrapper(collections.abc.MutableSequence):
+    """A wrapper for array-like structures.
 
     This implements all of the array like behavior that one would want,
     with a dirty-tracking mechanism to avoid constant validation costs.
@@ -52,7 +52,7 @@ class ArrayWrapper(collections.MutableSequence):
             return self.for_json() == other
 
     def __init__(self, ary):
-        """ Initialize a wrapper for the array
+        """Initialize a wrapper for the array
 
         Args:
             ary: (list-like, or ArrayWrapper)
@@ -64,10 +64,8 @@ class ArrayWrapper(collections.MutableSequence):
         """ Holds a typed copy of the array """
         self._typed = None
 
-        if isinstance(ary, (list, tuple, collections.Sequence)):
+        if isinstance(ary, (list, tuple, collections.abc.Sequence)):
             self.data = ary
-        elif isinstance(ary, ArrayWrapper):
-            self.data = ary.data
         else:
             raise TypeError("Invalid value given to array validator: {0}".format(ary))
 
@@ -120,7 +118,6 @@ class ArrayWrapper(collections.MutableSequence):
         return True
 
     def validate_uniqueness(self):
-
         if getattr(self, "uniqueItems", False) is True:
             testset = set(repr(item) for item in self.data)
             if len(testset) != len(self.data):
@@ -131,7 +128,6 @@ class ArrayWrapper(collections.MutableSequence):
                 )
 
     def validate_length(self):
-
         if getattr(self, "minItems", None) is not None:
             if len(self.data) < self.minItems:
                 raise ValidationError(
@@ -149,7 +145,7 @@ class ArrayWrapper(collections.MutableSequence):
                 )
 
     def validate_items(self):
-        """ Validates the items in the backing array, including
+        """Validates the items in the backing array, including
         performing type validation.
 
         Sets the _typed property and clears the dirty flag as a side effect
@@ -232,7 +228,7 @@ class ArrayWrapper(collections.MutableSequence):
 
     @staticmethod
     def create(name, item_constraint=None, **addl_constraints):
-        """ Create an array validator based on the passed in constraints.
+        """Create an array validator based on the passed in constraints.
 
         If item_constraint is a tuple, it is assumed that tuple validation
         is being performed. If it is a class or dictionary, list validation
@@ -251,7 +247,9 @@ class ArrayWrapper(collections.MutableSequence):
         )
         from python_jsonschema_objects import classbuilder
 
-        klassbuilder = addl_constraints.pop("classbuilder", None)
+        klassbuilder = addl_constraints.pop(
+            "classbuilder", None
+        )  # type: python_jsonschema_objects.classbuilder.ClassBuilder
         props = {}
 
         if item_constraint is not None:
@@ -290,23 +288,9 @@ class ArrayWrapper(collections.MutableSequence):
                             )
                         )
 
-                    uri = item_constraint["$ref"]
-                    if uri in klassbuilder.resolved:
-                        logger.debug(
-                            util.lazy_format(
-                                "Using previously resolved object for {0}", uri
-                            )
-                        )
-                    else:
-                        logger.debug(util.lazy_format("Resolving object for {0}", uri))
-
-                        with klassbuilder.resolver.resolving(uri) as resolved:
-                            # Set incase there is a circular reference in schema definition
-                            klassbuilder.resolved[uri] = klassbuilder.construct(
-                                uri, resolved, (classbuilder.ProtocolBase,)
-                            )
-
-                    item_constraint = klassbuilder.resolved[uri]
+                    item_constraint = klassbuilder.resolve_type(
+                        item_constraint["$ref"], name
+                    )
 
                 elif isdict and item_constraint.get("type") == "array":
                     # We need to create a sub-array validator.
@@ -318,27 +302,14 @@ class ArrayWrapper(collections.MutableSequence):
                 elif isdict and "oneOf" in item_constraint:
                     # We need to create a TypeProxy validator
                     uri = "{0}_{1}".format(name, "<anonymous_list_type>")
-                    type_array = []
-                    for i, item_detail in enumerate(item_constraint["oneOf"]):
-                        if "$ref" in item_detail:
-                            subtype = klassbuilder.construct(
-                                util.resolve_ref_uri(
-                                    klassbuilder.resolver.resolution_scope,
-                                    item_detail["$ref"],
-                                ),
-                                item_detail,
-                            )
-                        else:
-                            subtype = klassbuilder.construct(
-                                uri + "_%s" % i, item_detail
-                            )
-
-                        type_array.append(subtype)
+                    type_array = klassbuilder.construct_objects(
+                        item_constraint["oneOf"], uri
+                    )
 
                     item_constraint = classbuilder.TypeProxy(type_array)
 
                 elif isdict and item_constraint.get("type") == "object":
-                    """ We need to create a ProtocolBase object for this anonymous definition"""
+                    """We need to create a ProtocolBase object for this anonymous definition"""
                     uri = "{0}_{1}".format(name, "<anonymous_list_type>")
                     item_constraint = klassbuilder.construct(uri, item_constraint)
 
